@@ -150,7 +150,7 @@ class VWS:
         self._server_secret_key = server_secret_key
         self._base_vws_url = base_vws_url
 
-    def _make_request(
+    def make_request(
         self,
         method: str,
         data: bytes,
@@ -160,7 +160,7 @@ class VWS:
         """
         Make a request to the Vuforia Target API.
 
-        This uses `requests` to make a request against https://vws.vuforia.com.
+        This uses `requests` to make a request against Vuforia.
         The content type of the request will be `application/json`.
 
         Args:
@@ -168,24 +168,26 @@ class VWS:
             data: The request body which will be used in the request.
             request_path: The path to the endpoint which will be used in the
                 request.
-            expected_result_code: See
-                https://developer.vuforia.com/library/web-api/cloud-targets-web-services-api#result-codes
+            expected_result_code: See "VWS API Result Codes" on
+                https://developer.vuforia.com/library/web-api/cloud-targets-web-services-api.
 
         Returns:
             The response to the request made by `requests`.
 
         Raises:
-            ~vws.exceptions.OopsAnErrorOccurredPossiblyBadNameError: Vuforia
-                returns an HTML page with the text "Oops, an error occurred".
+            ~vws.exceptions.custom_exceptions.OopsAnErrorOccurredPossiblyBadNameError:
+                Vuforia returns an HTML page with the text "Oops, an error
+                occurred".
+
                 This has been seen to happen when the given name includes a bad
                 character.
             ~vws.exceptions.custom_exceptions.ServerError: There is an error
                 with Vuforia's servers.
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
-            json.decoder.JSONDecodeError: The server did not respond with valid
-                JSON. This may happen if the server address is not a valid
-                Vuforia server.
+            json.JSONDecodeError: The server did not respond with valid JSON.
+                This may happen if the server address is not a valid Vuforia
+                server.
         """
         response = _target_api_request(
             server_access_key=self._server_access_key,
@@ -309,14 +311,14 @@ class VWS:
 
         content = json.dumps(obj=data).encode(encoding="utf-8")
 
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.POST,
             data=content,
             request_path="/targets",
             expected_result_code="TargetCreated",
         )
 
-        return str(json.loads(response.text)["target_id"])
+        return str(json.loads(s=response.text)["target_id"])
 
     def get_target_record(self, target_id: str) -> TargetStatusAndRecord:
         """
@@ -346,7 +348,7 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.GET,
             data=b"",
             request_path=f"/targets/{target_id}",
@@ -354,7 +356,7 @@ class VWS:
         )
 
         result_data = json.loads(s=response.text)
-        status = TargetStatuses(result_data["status"])
+        status = TargetStatuses(value=result_data["status"])
         target_record_dict = dict(result_data["target_record"])
         target_record = TargetRecord(
             target_id=target_record_dict["target_id"],
@@ -442,14 +444,14 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.GET,
             data=b"",
             request_path="/targets",
             expected_result_code="Success",
         )
 
-        return list(json.loads(response.text)["results"])
+        return list(json.loads(s=response.text)["results"])
 
     def get_target_summary_report(self, target_id: str) -> TargetSummaryReport:
         """
@@ -479,16 +481,16 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.GET,
             data=b"",
             request_path=f"/summary/{target_id}",
             expected_result_code="Success",
         )
 
-        result_data = dict(json.loads(response.text))
+        result_data = dict(json.loads(s=response.text))
         return TargetSummaryReport(
-            status=TargetStatuses(result_data["status"]),
+            status=TargetStatuses(value=result_data["status"]),
             database_name=result_data["database_name"],
             target_name=result_data["target_name"],
             upload_date=date.fromisoformat(result_data["upload_date"]),
@@ -522,14 +524,14 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.GET,
             data=b"",
             request_path="/summary",
             expected_result_code="Success",
         )
 
-        response_data = dict(json.loads(response.text))
+        response_data = dict(json.loads(s=response.text))
         return DatabaseSummaryReport(
             active_images=response_data["active_images"],
             current_month_recos=response_data["current_month_recos"],
@@ -572,7 +574,7 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        self._make_request(
+        self.make_request(
             method=HTTPMethod.DELETE,
             data=b"",
             request_path=f"/targets/{target_id}",
@@ -609,7 +611,7 @@ class VWS:
             ~vws.exceptions.vws_exceptions.TooManyRequestsError: Vuforia is
                 rate limiting access.
         """
-        response = self._make_request(
+        response = self.make_request(
             method=HTTPMethod.GET,
             data=b"",
             request_path=f"/duplicates/{target_id}",
@@ -682,7 +684,9 @@ class VWS:
 
         if image is not None:
             image_data = _get_image_data(image=image)
-            image_data_encoded = base64.b64encode(image_data).decode("ascii")
+            image_data_encoded = base64.b64encode(s=image_data).decode(
+                encoding="ascii",
+            )
             data["image"] = image_data_encoded
 
         if active_flag is not None:
@@ -693,7 +697,7 @@ class VWS:
 
         content = json.dumps(obj=data).encode(encoding="utf-8")
 
-        self._make_request(
+        self.make_request(
             method=HTTPMethod.PUT,
             data=content,
             request_path=f"/targets/{target_id}",
